\def\PCTeXDate{2004/09/01}
\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{pcdiplom}[\PCTeXDate PC diploma thesis class]
\DeclareOption*{\PassOptionsToClass{\CurrentOption}{scrbook}}
\ProcessOptions\relax
\LoadClass[headsepline,pointlessnumbers,liststotoc,bibtotoc]{scrbook}
% oh yea, I want a LOT of packages! :-)
\RequirePackage[latin1]{inputenc}
\RequirePackage[T1]{fontenc}
\RequirePackage[english,ngerman]{babel}
\RequirePackage[fleqn]{amsmath}
\RequirePackage{amssymb}
\RequirePackage{listings}
\RequirePackage{times}
\RequirePackage{url}
\RequirePackage{ifthen}
\RequirePackage{color}
\@ifundefined{pdfoutput}{
  % this is used with normal latex
  \RequirePackage[dvips]{graphicx}
  \RequirePackage{pst-tree,pst-node,pstricks}
  \RequirePackage[ps2pdf]{hyperref}
}{
  % this is used with pdflatex
  \RequirePackage{ae}
  \RequirePackage{thumbpdf}
  \RequirePackage[pdftex]{graphicx}
  \RequirePackage{hyperref}
}

% own commands
% the ``Eidesstattliche Versicherung'' layout
\newcommand{\makeeid}[3]{
  \thispagestyle{plain}
  \vspace*{\fill}
  \section*{Erklrung}
  #1

  \bigskip

  \noindent{#2}

  \vspace{2cm}
  \hspace{8cm}
  \begin{minipage}{3.5cm}
    \hrule
    \vspace{1mm}
    \hspace{1mm}#3
  \end{minipage}
  \clearpage
  \if@twoside
    \thispagestyle{plain}
    \cleardoublepage
  \fi
}
% scrbook does not provide a abstract environment
\newenvironment{abstract}{
  \thispagestyle{plain}
  \vspace*{\fill}
  \section*{\begin{center}Zusammenfassung\end{center}}
}{
  \clearpage
  \if@twoside
    \thispagestyle{plain}
    \cleardoublepage
  \fi
}
% the thanks page
\newenvironment{thanksto}{
  \thispagestyle{plain}
  \vspace*{\fill}
  \section*{Danksagung}
  \parindent=0em
}{
  \clearpage
  \if@twoside
    \thispagestyle{plain}
    \cleardoublepage
  \fi
}
% ensure a pdfbookmark to the TOC
\let\pc@tableofcontents\tableofcontents
\renewcommand{\tableofcontents}{
  \pdfbookmark[0]{Inhaltsverzeichnis}{toc}
  \pc@tableofcontents
}
% a example environment :-)
\newenvironment{example}{
  \paragraph*{Beispiel}
}{
  \bigskip
}
% the TM symbol
\newcommand{\trademark}{\texttrademark}
% buzzwords are highlighted like this
\newcommand{\buzzword}[1]{\emph{#1}}
% and filenames like this
\newcommand{\filename}[1]{\texttt{\small #1}}
% sets in math
\newcommand{\set}[1]{\ensuremath{\left\{#1\right\}}}
% these commands are needed for the pcplain bibtex style
\newcommand{\btxandlong}{und}
\newcommand{\btxpageslong}{Seiten}

% some settings for the hyperref package
\definecolor{pdflink}{rgb}{0,0,0}
\definecolor{pdfanchor}{rgb}{0,0,0}
\definecolor{pdfcite}{rgb}{0,0,0}
\definecolor{pdffile}{rgb}{0,0,0}
\definecolor{pdfmenu}{rgb}{0,0,0}
\definecolor{pdfpage}{rgb}{0,0,0}
\definecolor{pdfurl}{rgb}{0,0,0}
\hypersetup{
  colorlinks=true,
  linkcolor=pdflink,
  anchorcolor=pdfanchor,
  citecolor=pdfcite,
  filecolor=pdffile,
  menucolor=pdfmenu,
  pagecolor=pdfpage,
  urlcolor=pdfurl,
  bookmarksnumbered=true,
  bookmarksopen=true,
}
\def\Hy@WarningNoLine#1{}
% some settings for the listings package
\lstloadlanguages{C++,Java}
\lstset{language=ML,
  basicstyle=\fontshape{tt}\selectfont\small, %schriftgroesse
  stringstyle=\fontshape{it}\selectfont,
  commentstyle=\rmfamily\fontshape{it}\selectfont,
  breaklines=true,   
  keywordstyle=\bfseries,
  mathescape=true,
  extendedchars=true,
  frameround=ffff,
  framexleftmargin=5mm,
  frame=shadowbox,
  rulesepcolor=\color{black},
  numbers=left,
  numberstyle=\tiny,
  stepnumber=1,
  numbersep=5pt
}
\definecolor{lstbg}{rgb}{0.95,0.95,0.95}
% urls in sans serif
\urlstyle{sf}
% stretch whitespace up to that level to avoid overful hboxes
\emergencystretch=12pt
% Sometimes when you typset something in LaTeX you will find that a
% single word or a few of them ends by them selves on an otherwise blank
% page. This is called "orphans" if it is at the bottom of a page or
% "widowed" if they are at the top in typographic lingo and is generally
% something that TeX handles pretty well (at least better then Word),
% but in some occasions it still happens.
% 
% You can avoid this by setting the following penalty values.
% 
% This makes it rather hard for LaTeX to "break the rule" and typeset
% orphans or widows. However it is still possible in some situations
% they will still occur.
% 
% It is not recommendet to set this to 10000, bad things can happen then
% when LaTeX can never break this rule.
\clubpenalty=9999
\widowpenalty=9999
\endinput
